Module blaxel.core.client.models.sandbox_lifecycle
==================================================

Classes
-------

`SandboxLifecycle(expiration_policies: blaxel.core.client.types.Unset | list['ExpirationPolicy'] = <blaxel.core.client.types.Unset object>)`
:   Lifecycle configuration for sandbox management
    
    Attributes:
        expiration_policies (Union[Unset, list['ExpirationPolicy']]): List of expiration policies
    
    Method generated by attrs for class SandboxLifecycle.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `expiration_policies`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :